#!/bin/bash
#Pre-Upgrade-Check
#   Os is trusty?
#   CamTrace installed version is 14.0.0 or superior?
#   Enough space on disk?

error() {
    #Echo & exit
    echo "$1"
    exit 1
}

puc_release=$(lsb_release -cs)
if [[ "${puc_release}" != "trusty" ]];then
    error "Migration-Check : Bad OS Codename [${puc_release} != trusty]"
fi
echo "Migration-Check : OS Codename [${puc_release}] : OK"

puc_version=$(dpkg-query --show --showformat='${Version}\n' camtrace)
if [[ "${puc_version}" < "14.0.0" ]];then
    error "Migration-Check : Wrong camtrace Version [${puc_version} < 14.0.0]"
fi
echo "Migration-Check : camtrace version [${puc_version}] : OK"

puc_versionsys=$(dpkg-query --show --showformat='${Version}\n' camtrace-sys)
if [[ "${puc_versionsys}" < "14.0.0" ]];then
    error "Migration-Check : Wrong camtrace-sys Version [${puc_versionsys} < 14.0.0]"
fi
echo "Migration-Check : camtrace-sys version [${puc_versionsys}] : OK"

puc_status=$(dpkg-query --show --showformat='${Status}\n' camtrace)
if [[ "${puc_status}" != "install ok installed" ]];then
    error "Migration-Check : Wrong camtrace Status [${puc_status} != install ok installed]"
fi
echo "Migration-Check : camtrace Status [${puc_status}] : OK"

puc_statussys=$(dpkg-query --show --showformat='${Status}\n' camtrace-sys)
if [[ "${puc_statussys}" != "install ok installed" ]];then
    error "Migration-Check : Wrong camtrace-sys Status [${puc_statussys} != install ok installed]"
fi
echo "Migration-Check : camtrace-sys Status [${puc_statussys}] : OK"

OKBYTES="3400000"  # OKBYTES is uploaded package size + untared package size
rootavail=$(df -k --output=avail /|tail -1)
if [[ "${rootavail}" -lt "${OKBYTES}" ]];then
    error "Migration-Check : Not enough space on / [${rootavail} < ${OKBYTES}]"
fi
echo "Migration-Check : space left on / [${rootavail}] : OK"

## LIC CHECK (only no lic - demo mode - or new lic format is ok)
test -f /opt/camtrace/etc/scamd.key && {
    gpg --homedir /opt/camtrace/etc/.key --quiet --decrypt /opt/camtrace/etc/scamd.key >/dev/null 2>&1 || \
        error "Migration-Check : Bad or Obsolete License detected"
}
echo "Migration-Check : license version : OK"

exit 0
